summaryrefslogtreecommitdiffstats
path: root/src/include/usr/diag
diff options
context:
space:
mode:
authorZane Shelley <zshelle@us.ibm.com>2013-02-23 15:05:54 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-03-15 14:24:11 -0500
commit74ac56cc753d903dce8d7515e88f4a2880637c4c (patch)
tree839b7860f4ad422686f0f971865fcddceb84a4d2 /src/include/usr/diag
parentf6ffa742eb8598a9313e6ca59e52e7e13a7faf3d (diff)
downloadtalos-hostboot-74ac56cc753d903dce8d7515e88f4a2880637c4c.tar.gz
talos-hostboot-74ac56cc753d903dce8d7515e88f4a2880637c4c.zip
General cleanup of some PRD code.
Fixed some coding guideline issues. Cleaned up the function definitions of startScrub and restoreDramRepairs. Fixed issue in prdfLogParse.C where PlatServices was getting pulled into x86.nfp parser because of an include dependency. Change-Id: I9eb89466086810ec570a5a46e99cf4987f6679c9 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/3310 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com> Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/3587
Diffstat (limited to 'src/include/usr/diag')
-rwxr-xr-xsrc/include/usr/diag/prdf/common/prdfMain_common.H3
-rw-r--r--src/include/usr/diag/prdf/prdfMain.H6
2 files changed, 5 insertions, 4 deletions
diff --git a/src/include/usr/diag/prdf/common/prdfMain_common.H b/src/include/usr/diag/prdf/common/prdfMain_common.H
index 76108356f..9d2b2493b 100755
--- a/src/include/usr/diag/prdf/common/prdfMain_common.H
+++ b/src/include/usr/diag/prdf/common/prdfMain_common.H
@@ -154,7 +154,8 @@ extern errlHndl_t initialize();
* containing the analysis; otherwise, for other attention types, PRD
* commits the error log itself and NULL is returned.
*/
-extern errlHndl_t main(ATTENTION_VALUE_TYPE i_attnType, const AttnList & i_attnList);
+extern errlHndl_t main( ATTENTION_VALUE_TYPE i_attnType,
+ const AttnList & i_attnList );
/**
* @brief Clean up pieces of PRD for fresh IPLs.
diff --git a/src/include/usr/diag/prdf/prdfMain.H b/src/include/usr/diag/prdf/prdfMain.H
index 94c52bbb7..653d7c508 100644
--- a/src/include/usr/diag/prdf/prdfMain.H
+++ b/src/include/usr/diag/prdf/prdfMain.H
@@ -44,11 +44,11 @@ namespace PRDF
/**
* @brief Restores hardware DRAM repairs to reflect what is stored in VPD.
* @param i_mbaTarget An MBA target.
* @return Non-SUCCESS if conditions are such that a callout had to be made,
- * SUCCESS othewise.
+ * SUCCESS otherwise.
*/
-extern int32_t restoreDramRepairs(const TARGETING::TargetHandle_t i_mbaTarget);
+extern int32_t restoreDramRepairs( const TARGETING::TargetHandle_t i_mba );
} // end namespace PRDF
OpenPOWER on IntegriCloud
@@ -44,11 +44,11 @@ namespace PRDF
/**
* @brief Restores hardware DRAM repairs to reflect what is stored in VPD.
- * @param i_mbaTarget An MBA target.
+ * @param i_mba An MBA target.
* @return Non-SUCCESS if conditions are such that a callout had to be made,